summaryrefslogtreecommitdiffstats
path: root/wp-admin/update.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-admin/update.php')
-rw-r--r--wp-admin/update.php25
1 files changed, 13 insertions, 12 deletions
diff --git a/wp-admin/update.php b/wp-admin/update.php
index be95102..c3cd289 100644
--- a/wp-admin/update.php
+++ b/wp-admin/update.php
@@ -2,8 +2,8 @@
require_once('admin.php');
-if ( !current_user_can('edit_plugins') )
- wp_die('<p>'.__('You do not have sufficient permissions to update plugins for this blog.').'</p>');
+if ( ! current_user_can('update_plugins') )
+ wp_die(__('You do not have sufficient permissions to update plugins for this blog.'));
function request_filesystem_credentials($form_post, $type = '', $error = false) {
$req_cred = apply_filters('request_filesystem_credentials', '', $form_post, $type, $error);
@@ -45,19 +45,19 @@ function request_filesystem_credentials($form_post, $type = '', $error = false)
<p><?php _e('To perform the requested update, FTP connection information is required.') ?></p>
<table class="form-table">
<tr valign="top">
-<th scope="row"><?php _e('Hostname:') ?></th>
+<th scope="row"><label for="hostname"><?php _e('Hostname:') ?></label></th>
<td><input name="hostname" type="text" id="hostname" value="<?php echo attribute_escape($hostname) ?>"<?php if( defined('FTP_HOST') ) echo ' disabled="disabled"' ?> size="40" /></td>
</tr>
<tr valign="top">
-<th scope="row"><?php _e('Username:') ?></th>
+<th scope="row"><label for="username"><?php _e('Username:') ?></label></th>
<td><input name="username" type="text" id="username" value="<?php echo attribute_escape($username) ?>"<?php if( defined('FTP_USER') ) echo ' disabled="disabled"' ?> size="40" /></td>
</tr>
<tr valign="top">
-<th scope="row"><?php _e('Password:') ?></th>
+<th scope="row"><label for="password"><?php _e('Password:') ?></label></th>
<td><input name="password" type="password" id="password" value=""<?php if( defined('FTP_PASS') ) echo ' disabled="disabled"' ?> size="40" /><?php if( defined('FTP_PASS') && !empty($password) ) echo '<em>'.__('(Password not shown)').'</em>'; ?></td>
</tr>
<tr valign="top">
-<th scope="row"><?php _e('Use SSL:') ?></th>
+<th scope="row"><label for="ssl"><?php _e('Use SSL:') ?></label></th>
<td>
<select name="ssl" id="ssl"<?php if( defined('FTP_SSL') ) echo ' disabled="disabled"' ?>>
<?php
@@ -110,15 +110,16 @@ function do_plugin_upgrade($plugin) {
return;
}
- $was_activated = is_plugin_active($plugin); //Check now, It'll be deactivated by the next line if it is,
+ $was_activated = is_plugin_active($plugin); //Check now, It'll be deactivated by the next line if it is
$result = wp_update_plugin($plugin, 'show_message');
if ( is_wp_error($result) ) {
show_message($result);
+ show_message( __('Installation Failed') );
} else {
- //Result is the new plugin file relative to PLUGINDIR
- show_message(__('Plugin upgraded successfully'));
+ //Result is the new plugin file relative to WP_PLUGIN_DIR
+ show_message( __('Plugin upgraded successfully') );
if( $result && $was_activated ){
show_message(__('Attempting reactivation of the plugin'));
echo '<iframe style="border:0" width="100%" height="170px" src="' . wp_nonce_url('update.php?action=activate-plugin&plugin=' . $result, 'activate-plugin_' . $result) .'"></iframe>';
@@ -151,8 +152,8 @@ if ( isset($_GET['action']) ) {
<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php echo get_option('blog_charset'); ?>" />
<title><?php bloginfo('name') ?> &rsaquo; <?php _e('Plugin Reactivation'); ?> &#8212; <?php _e('WordPress'); ?></title>
<?php
-wp_admin_css( 'css/global' );
-wp_admin_css( 'css/colors' );
+wp_admin_css( 'global', true );
+wp_admin_css( 'colors', true );
?>
</head>
<body>
@@ -164,7 +165,7 @@ wp_admin_css( 'css/colors' );
echo '<p>' . __('Plugin failed to reactivate due to a fatal error.') . '</p>';
error_reporting( E_ALL ^ E_NOTICE );
@ini_set('display_errors', true); //Ensure that Fatal errors are displayed.
- include(ABSPATH . PLUGINDIR . '/' . $plugin);
+ include(WP_PLUGIN_DIR . '/' . $plugin);
}
echo "</body></html>";
}